pub struct ParsingNumberError { /* private fields */ }Expand description
Error type for parsing number-related errors. This error type encapsulates specific parsing errors for fractions, floating-point numbers, and numbers in standard form.
Implementations
Sourceimpl ParsingNumberError
impl ParsingNumberError
Sourcepub fn fraction(&self) -> &ParsingFractionError
pub fn fraction(&self) -> &ParsingFractionError
Retrieves a reference to the parsing error related to fractions.
Sourcepub fn double(&self) -> &ParseFloatError
pub fn double(&self) -> &ParseFloatError
Retrieves a reference to the parsing error related to floating-point numbers.
Sourcepub fn standardform(&self) -> &ParsingStandardFormError
pub fn standardform(&self) -> &ParsingStandardFormError
Retrieves a reference to the parsing error related to numbers in standard form.